#
# This file is part of pyasn1-alt-modules software.
#
# Created by Russ Housley.
#
# Copyright (c) 2019-2024, Vigil Security, LLC
# License: http://vigilsec.com/pyasn1-alt-modules-license.txt
#
# Certificate Image in the Internet X.509 Public Key Infrastructure
#
# ASN.1 source from:
# https://www.rfc-editor.org/rfc/rfc6170.txt
#

from pyasn1.type import univ

id_logo_certImage = univ.ObjectIdentifier('1.3.6.1.5.5.7.20.3')
